@@ -41,7 +41,7 @@ outOfIndependence=function(data,Gvec,labs,nolabs=FALSE,fixmarg=TRUE,firstfew=0,s
     #topfew=which(abs(devP[,jj]*sqrt(n))>1)
     #print(labs[topfew])
     dfP[[jj]]=data.frame(value=devP[,jj]*sqrt(n),place=1:nrow(devP),lbls=labs,stringsAsFactors = TRUE)
-    sortOp[[jj]]=sort(abs(dfP[[jj]]$value),decreasing=T,index.return=T)
+    sortOp[[jj]]=sort(abs(dfP[[jj]]$value),decreasing=TRUE,index.return=TRUE)
     #   sortOp2=sort(abs(dfP2$value),decreasing=T,index.return=T)
     #   sortOp3=sort(abs(dfP3$value),decreasing=T,index.return=T)  
     
@@ -74,7 +74,8 @@ outOfIndependence=function(data,Gvec,labs,nolabs=FALSE,fixmarg=TRUE,firstfew=0,s
    #   bbp=bbp+xlab(paste("Standardized residuals")) + ylab(paste("Variable categories"))          
       if(firstfew==0){bbp=bbp+theme(axis.line=element_blank(),axis.ticks = element_blank())}
     }
-    if(nolabs==F){
+   
+    if(nolabs==FALSE){
       bbp=bbp+geom_text(data=dfP[[jj]],aes(label=lbls),size=textSize)
     }
     bp[[jj]]=bbp
